/**
* @license Apache-2.0
*
* Copyright (c) 2021 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

// MODULES //

var isTypedArray = require( '@stdlib/assert-is-typed-array' );
var isDataView = require( '@stdlib/assert-is-dataview' );


// MAIN //

/**
* Polyfill for determining whether an object is an array buffer view.
*
* ## Notes
*
* -   This polyfill should only be used in environments which do not provide native `ArrayBuffer.isView` support.
* -   The implementation checks whether a value is a data view or typed array.
*
* @param {*} value - value to test
* @returns {boolean} boolean indicating whether value is an array buffer view
*
* @example
* var Int8Array = require( '@stdlib/array-int8' );
* var bool = isArrayBufferView( new Int8Array( 10 ) );
* // returns true
*
* @example
* var bool = isArrayBufferView( [] );
* // returns false
*/
function isArrayBufferView( value ) {
	return isTypedArray( value ) || isDataView( value );
}


// EXPORTS //

module.exports = isArrayBufferView;
